#
# spec file for package iwd
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           iwd
Version:        0.13
Release:        21.9
Summary:        Wireless daemon for Linux
License:        LGPL-2.1-or-later
Group:          Productivity/Networking/Other
URL:            https://git.kernel.org/pub/scm/network/wireless/iwd.git
Source:         https://kernel.org/pub/linux/network/wireless/%{name}-%{version}.tar.xz
Source2:        https://kernel.org/pub/linux/network/wireless/%{name}-%{version}.tar.sign
# https://www.kernel.org/doc/wot/holtmann.html
Source3:        %{name}.keyring
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(ell) >= 0.16
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}

%description
The iNet Wireless Daemon (iwd) project provides a wireless
connectivity solution. It attempts to optimise resource utilisation
of storage, runtime memory and link-time costs. It utilises the
features provided by the Linux kernel.

%prep
%setup -q

%build
%configure \
  --libexecdir=%{_libexecdir}/%{name} --enable-external-ell
make %{?_smp_mflags} V=1

%install
%make_install

mkdir -p %{buildroot}%{_sbindir}/
ln -s service %{buildroot}%{_sbindir}/rc%{name}

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license COPYING
%doc AUTHORS ChangeLog README
%{_bindir}/iwctl
%{_bindir}/iwmon
%{_sbindir}/rc%{name}
%{_libexecdir}/%{name}/
%{_unitdir}/%{name}.service
%if 0%{?suse_version} >= 1500
%dir %{_datadir}/dbus-1/system.d/
%{_datadir}/dbus-1/system.d/%{name}*.conf
%else
%{_sysconfdir}/dbus-1/system.d/%{name}*.conf
%endif
%{_datadir}/dbus-1/system-services/*%{name}.service

%changelog
* Thu Dec 13 2018 Jan Engelhardt <jengelh@inai.de>
- Avoid using bundled copy of ell
* Thu Dec 13 2018 mardnh@gmx.de
- Update to version 0.13:
  * Fix issue with WSC interface runtime handling.
  * Add support for Opportunistic Wireless Encryption.
  * Add support for common EAP-TLS framework.
* Sat Nov 17 2018 sean@suspend.net
- Update to version 0.12:
  * build: require at least version 0.15 when building ext ELL
  * network: simplify is_rsn logic
  * network: Check autoconnectable as the first condition
  * network: Introduce __bss_is_sae
  * scan: make scan_bss_get_rsn_info const correct
  * network: fix 8021x autoconnect
  * station: only set 8021x networks
  * client: fix mem leak
* Tue Oct 23 2018 sean@suspend.net
- Update to version 0.10:
  * Fix issue with Ethernet authentication packet handling
  * Fix issue with ad-hoc network scan results in station mode
  * Fix issue with cancellation of ongoing rekey offload
  * Add support for setting per-mac GTK credentials
  * Add support for using external Embedded Linux library
* Tue Oct  9 2018 sor.alexei@meowr.ru
- Update to version 0.9:
  * Fix an issue with handling EAP-WSC passwords.
  * Add support for TTLS-CHAP and TTLS-PAP.
  * Add support for handling FT over SAE.
* Mon Sep 24 2018 sor.alexei@meowr.ru
- Update to version 0.8:
  * Fix issue with handling EAP_CACHE_NEVER secret types.
  * Fix issue with redundant usage of the L flag and PEAP.
  * Fix issue with EAP type 33 as termination mechanism for PEAPv1.
  * Add initial version of Ethernet authentication daemon.
  * Add support for Station mode interface.
* Tue Sep 11 2018 astieger@suse.com
- add upstream signing key and validate source signature
* Tue Sep 11 2018 sor.alexei@meowr.ru
- Update to version 0.7 (changes since 0.4):
  * Fix an issue with EAPoL handling and Ad-Hoc networks.
  * Add support for using agent with EAP-GTC methods.
  * Add support for improved Known Networks management.
  * Add support for Simultaneous Authentication of Equals.
  * Add support for exposing supported modes of operation.
  * Add support for D-Bus auto-activation via systemd.
  * Fix an issue with synching the PSK on first connection.
  * Fix an issue with unnecessary known object removal events.
  * Fix an issue with hard coded peer address and SAE networks.
  * Fix an issue with raw passphrase requirement and SAE networks.
  * Fix an issue with differentiating authenticator and supplicant.
  * Fix an issue with timestamps comparison of known networks.
  * Fix an issue with handling cancellation of power callbacks.
  * Fix an issue with honouring auto-connect setting on power up.
  * Fix an issue with a crash during operstate callbacks.
* Fri Jul 27 2018 sor.alexei@meowr.ru
- Update to version 0.4:
  * Fix an issue with handling all zero PMKID.
  * Fix an issue with handling PEAP servers and M bit requirement.
  * Fix an issue with handling MS-CHAP v2 and uninitialised memory.
  * Fix an issue with handling a memory leak and aborting
    connections.
  * Fix an issue with handling a memory leak and PSK configuration.
  * Fix an issue with handling a not yet running D-Bus daemon.
  * Add support for advanced scanning of hidden networks.
  * Add support for MAC address randomisation.
  * Add support for the Ad-Hoc network interface.
  * Add support for the Access Point interface.
* Fri Jul 27 2018 jengelh@inai.de
- Trim marketing wording and false statements from description.
* Sat Jun 30 2018 sor.alexei@meowr.ru
- Initial package.
